EffectRenderStyle enum

表现模式控制的是“空间感策略”,不是性能档位。

之所以不用多个布尔开关去分别控制前后景、速度差和透视缩放, 是因为这几个维度本来就应该协同工作,拆开以后很容易出现组合失真。

Inheritance
Available extensions

Values

flat → const EffectRenderStyle

单层表现,适合作为最稳妥的基础模式。

layered → const EffectRenderStyle

提供适度的前后景分层和速度差,适合大多数正式页面。

cinematic → const EffectRenderStyle

在 layered 的基础上进一步强化景深和动态感,适合作为主视觉模式。

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolveDepth(Random random) double

Available on EffectRenderStyle, provided by the EffectRenderStyleDepthExtension extension

resolveOpacityScale(double depth) double

Available on EffectRenderStyle, provided by the EffectRenderStyleDepthExtension extension

resolvePerspectiveScale(double depth) double

Available on EffectRenderStyle, provided by the EffectRenderStyleDepthExtension extension

resolveSpeedScale(double depth) double

Available on EffectRenderStyle, provided by the EffectRenderStyleDepthExtension extension

toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<EffectRenderStyle>
A constant List of the values in this enum, in order of their declaration.