FireflyEffect class
萤火虫效果配置。
萤火虫和雨雪这类“整体向下”的粒子不同, 重点不在重力感,而在轻微游走和若隐若现的发光节奏。 这里暴露的参数也围绕这两个核心点展开,避免塞进太多难以感知的细碎开关。
- Inheritance
-
- Object
- AmbientEffectConfig
- FireflyEffect
Constructors
- FireflyEffect({FireflyIntensity intensity = FireflyIntensity.medium, double speed = 1.0, double opacity = 0.95, int? particleCount, double minSize = 1.8, double maxSize = 3.8, double wander = 1.0, double blinkSpeed = 1.0, Color glowColor = const Color(0xFFF3F08A), Color coreColor = const Color(0xFFFFF9D1)})
-
const
- FireflyEffect.heavy()
-
const
- FireflyEffect.light()
-
const
- FireflyEffect.medium()
-
const
Properties
- blinkSpeed → double
-
final
- coreColor → Color
-
final
- glowColor → Color
-
final
- hashCode → int
-
The hash code for this object.
no setteroverride
- intensity → FireflyIntensity
-
final
- maxSize → double
-
final
- minSize → double
-
final
- opacity → double
-
final
- particleCount → int?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- speed → double
-
final
- type → AmbientEffectType
-
no setteroverride
- wander → double
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
override